@@ -10,14 +10,17 @@ html_str.regulartable <- function( x ){
   out <- "<table>"
 
   if( nrow_part(x, "header") > 0 ){
+    x$header <- correct_h_border(x$header)
     tmp <- format(x$header, type = "html", header = TRUE)
     out = paste0(out, "<thead>", tmp, "</thead>" )
   }
   if( nrow_part(x, "body") > 0 ){
+    x$body <- correct_h_border(x$body)
     tmp <- format(x$body, type = "html", header = FALSE)
     out = paste0(out, "<tbody>", tmp, "</tbody>" )
   }
   if( nrow_part(x, "footer") > 0 ){
+    x$footer <- correct_h_border(x$footer)
     tmp <- format(x$footer, type = "html", header = FALSE)
     out = paste0(out, "<tfoot>", tmp, "</tfoot>" )
   }
