@@ -12,7 +12,7 @@
 #' ft_merge
 #' @export
 merge_v <- function(x, j = NULL, part = "body" ){
-  part <- match.arg(part, c("body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("body", "header", "footer"), several.ok = FALSE )
 
   j <- get_columns_id(x[[part]], j = j )
   j <- x$col_keys[j]
@@ -39,7 +39,7 @@ merge_v <- function(x, j = NULL, part = "body" ){
 #' @export
 merge_h <- function(x, i = NULL, part = "body" ){
 
-  part <- match.arg(part, c("body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("body", "header", "footer"), several.ok = FALSE )
 
   i <- get_rows_id( x[[part]], i )
 
@@ -71,11 +71,11 @@ merge_h <- function(x, i = NULL, part = "body" ){
 #' ft
 merge_none <- function(x, part = "all" ){
 
-  part <- match.arg(part, c("all", "body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
   if( part == "all" ){
     args <- list()
-    for( p in c("header", "body") ){
+    for( p in c("header", "footer", "body") ){
       x <- merge_none(x = x, part = p )
     }
   }
@@ -102,7 +102,7 @@ merge_none <- function(x, part = "all" ){
 #' ft_merge
 #' @export
 merge_at <- function(x, i = NULL, j = NULL, part = "body" ){
-  part <- match.arg(part, c("body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("body", "header", "footer"), several.ok = FALSE )
 
   j <- get_columns_id(x[[part]], j = j )
   j <- x$col_keys[j]
