@@ -3,15 +3,31 @@ pml_flextable <- function(value){
   dims <- dim(value)
   widths <- dims$widths
   colswidths <- paste0("<a:gridCol w=\"", round(widths*914400, 0), "\"/>", collapse = "")
+  hlinks <- character(0)
 
   out = paste0(out,  "<a:tblPr/><a:tblGrid>" )
   out = paste0(out,  colswidths )
   out = paste0(out,  "</a:tblGrid>" )
 
-  if( !is.null(value$header) )
-    out = paste0(out, format(value$header, header = TRUE, type = "pml") )
-  if( !is.null(value$body) )
-    out = paste0(out, format(value$body, header = FALSE, type = "pml") )
+  if( nrow_part(value, "header") > 0 ){
+    value$header <- correct_h_border(value$header)
+    xml_content <- format(value$header, header = TRUE, type = "pml")
+    out = paste0(out, xml_content )
+    hlinks <- append( hlinks, attr(xml_content, "htxt")$href )
+  }
+  if( nrow_part(value, "body") > 0 ){
+    value$body <- correct_h_border(value$body)
+    xml_content <- format(value$body, header = FALSE, type = "pml")
+    out = paste0(out, xml_content )
+    hlinks <- append( hlinks, attr(xml_content, "htxt")$href )
+  }
+  if( nrow_part(value, "footer") > 0 ){
+    value$footer <- correct_h_border(value$footer)
+    xml_content <- format(value$footer, header = FALSE, type = "pml")
+    out = paste0(out, xml_content )
+    hlinks <- append( hlinks, attr(xml_content, "htxt")$href )
+  }
+
   out = paste0(out,  "</a:tbl>" )
 
   graphic_frame <- paste0(
@@ -35,6 +51,7 @@ pml_flextable <- function(value){
     "</a:graphic>",
     "</p:graphicFrame>"
   )
+  attr(graphic_frame, "hlinks") <- hlinks
   graphic_frame
 }
 
@@ -46,7 +63,7 @@ pml_flextable <- function(value){
 #' functions \code{\link{width}}, \code{\link{height}}, \code{\link{autofit}}
 #' and \code{\link{dim_pretty}} instead. The overall size is resulting from
 #' cells, paragraphs and text properties (i.e. padding, font size, border widths).
-#' @param x a pptx device
+#' @param x an rpptx device
 #' @param value \code{flextable} object
 #' @param type placeholder type
 #' @param index placeholder index (integer). This is to be used when a placeholder type
@@ -63,9 +80,19 @@ pml_flextable <- function(value){
 #' \donttest{print(doc, target = "test.pptx" )}
 #' }
 #' @importFrom officer ph_from_xml
+#' @importFrom stringr fixed
 ph_with_flextable <- function( x, value, type = "body", index = 1 ){
   stopifnot(inherits(x, "rpptx"))
   graphic_frame <- pml_flextable(value)
+
+  hlinks <- attr(graphic_frame, "hlinks")
+  if( length(hlinks) > 0 ){
+    for( hl in hlinks ){
+      slide <- x$slide$get_slide(x$cursor)
+      rel <- slide$relationship()
+      graphic_frame <- process_url(rel, url=hl, str = graphic_frame, pattern = "a:hlinkClick")
+    }
+  }
   ph_from_xml(x = x, value = graphic_frame, type = type, index = index )
 }
 
@@ -77,6 +104,16 @@ ph_with_flextable_at <- function( x, value, left, top ){
   stopifnot(inherits(x, "rpptx"))
   stopifnot(inherits(x, "rpptx"))
   graphic_frame <- pml_flextable(value)
+
+  hlinks <- attr(graphic_frame, "hlinks")
+  if( length(hlinks) > 0 ){
+    for( hl in hlinks ){
+      slide <- x$slide$get_slide(x$cursor)
+      rel <- slide$relationship()
+      graphic_frame <- process_url(rel, url=hl, str = graphic_frame, pattern = "a:hlinkClick")
+    }
+  }
+
   ph_from_xml_at(x = x, value = graphic_frame, left = left, top = top,
                  width = 0, height = 0 )
 }
